##############################################################################
##
## Enable-ZenFirewallRules
##
## by Actian Corporation (http://www.actian.com/zen)
##
##############################################################################

    <#
    .NOTES
        Copyright (c) Actian Corporation.  All rights reserved.

        Use of this sample source code is subject to the terms of the Actian
        Zen license agreement under which you licensed this sample source code.
        If you did not accept the terms of the license agreement, you are not
        authorized to use this sample source code. For the terms of the license,
        please see the license agreement between you and Actian Corporation.
        THE SAMPLE SOURCE CODE IS PROVIDED "AS IS", WITH NO WARRANTIES.

    .SYNOPSIS
        Enables Zen firewall rules on one or more of the Windows Firewall profiles.

    .DESCRIPTION
        Allows communication through the Windows Firewall by enabling the installed
        Zen firewall rules on one or more of the Windows Firewall profiles. If no
        parameters are specified, the Zen firewall rules will be enabled for all
        Windows Firewall profiles (domain, private, and public).

    .PARAMETER any
        (Default) Enables the Zen firewall rules on all Windows Firewall profiles.

    .PARAMETER domain
        Enables the Zen firewall rules on the Windows Firewall domain profile only.

    .PARAMETER private
        Enables the Zen firewall rules on the Windows Firewall private profile only.

    .PARAMETER public
        Enables the Zen firewall rules on the Windows Firewall public profile only.
        
    .EXAMPLE
        PS C:\> .\Enable-ZenFirewallRules any
            Enables the Zen firewall rules on all Windows Firewall profiles.

    .EXAMPLE
        PS C:\> .\Enable-ZenFirewallRules domain
            Enables the Zen firewall rules on the Windows Firewall domain profile only.

    .EXAMPLE
        PS C:\> .\Enable-ZenFirewallRules private
            Enables the Zen firewall rules on the Windows Firewall private profile only.

    .EXAMPLE
        PS C:\> .\Enable-ZenFirewallRules public
            Enables the Zen firewall rules on the Windows Firewall public profile only.

    .INPUTS
        None. You cannot pipe objects to this cmdlet.

    .OUTPUTS
        After the rules are enabled the current state of all installed rules is displayed.

    #>

param (
    [Parameter(
        Mandatory=$false,
        Position = 0)]
    [ValidateSet('any','domain','private','public')]
    [String]
    $fwProfile="any"
)

Set-StrictMode -Version Latest

Import-LocalizedData msg -FileName "Zen_PowerShell_Script_strings.psd1" -ErrorAction SilentlyContinue

#############################
## Abort Checks
#############################
# -- Using built-in PowerShell Requires keyword.
#Requires -Version 5.1                            # -- Require PowerShell 5.1 or higher (Nano Server,IoT).
#Requires -PSEdition Core                         # -- Require PowerShell Core
#Requires -RunAsAdministrator                     # -- Require PowerShell running as Administrator.

function Main {
    ##########################
    # Defines the processing order of this script.
    ##########################
    EnablePsqlFirewallRules
}
function EnablePsqlFirewallRules {
    ##########################
    # Enable all installed Zen firewall rules on the specified profile.
    ##########################
    $moduleNetSecurity=$false
    Get-Command -CommandType Function | ForEach-Object -Process {if ($_.Source -eq "NetSecurity") {$moduleNetSecurity=$true} }
    if ($moduleNetSecurity) {
        Import-Module -Name NetSecurity  # -- Firewall rule cmdlets.
    } else {
        # -- The NetSecurity Module is not installed, warn user and exit function.
        $msg.warnNoNetSecModify
        ""
        return
    }
    Try { Set-NetFirewallRule -DisplayName "Actian Zen*" -Enabled True -Profile $fwProfile }
    Catch { $msg.failToEnableRules -f $fwProfile }
    Get-NetFirewallRule -DisplayName "Actian Zen*"
}

Try {. Main}
Catch {throw $msg.errUnknown; exit -1}